@@ -31,13 +31,28 @@
     scanning
     --------
 
-    At the moment a single metho to do a simple time course parameter scan
+    At the moment a single method to do a simple time course parameter scan
+    
+    fitModel
+    --------
+    
+    A helper class to make it much easier to fit models using lmfit
+    
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-from . import odePrint
-from . import plotting
-from . import prettyTabular
-from . import buildNetworks
-from . import scanning
+try:
+    from . import odePrint
+    from . import plotting
+    from . import prettyTabular
+    from . import buildNetworks
+    from . import scanning
+    from . import model_fitter
+except:
+    from teUtils import odePrint
+    from teUtils import plotting
+    from teUtils import prettyTabular
+    from teUtils import buildNetworks
+    from teUtils import scanning
+    from teUtils import model_fitter
