@@ -15,7 +15,7 @@ def _getMARateLaw (k, s1, s2):
     return 'k' + str (k) + '0*' + s1 + ' - k' + str (k) + '1' + '*' + s2
 
 
-def getLinearChain (lengthOfChain, rateLawType='MassAction', MaxKeq=5):
+def getLinearChain (lengthOfChain, rateLawType='MassAction', keqRatio=5):
     """ Return an Antimony string for a linear chain
     
     Parameters 
@@ -23,20 +23,16 @@ def getLinearChain (lengthOfChain, rateLawType='MassAction', MaxKeq=5):
         arg1 (integer): Length of generated chain, number of reactions
          
         arg2 (rateLawType String): Optional, can be 'MassAction' (default) or 'Michaelis'
-             Michaelis generate reversible Miachaeli-Menten rate laws.  
   
-        arg3 (MaxKeq float): Optional, maximum size of equilibrium constant
+        arg3 (float): Optional, maximum size of equilibrium constant
          
     Return
     ------
     result: Antimony string
     
     Example
-    -------  
-    >>> # Generate linear chain of 5 steps with a maximum Keq of 6   
-    >>> s = teUtils.buildNetworks.getLinearChain (5, 'MassAction', 6)
-    >>>
-    >>> s = teUtils.buildNetworks.getLinearChain (5, 'Michaelis', 6)
+    -------     
+    >>> s = teUtils.buildNetworks.getLinearChain ('MassAction', 6)
     >>> r = te.loada (s)
     >>> r.simulate (0, 50, 100)
     >>> r.plot()
@@ -74,7 +70,7 @@ def getLinearChain (lengthOfChain, rateLawType='MassAction', MaxKeq=5):
     # Initialize values
     if rateLawType == 'MassAction':
        for i in range (n):
-           model += 'k' + str (i+1) + '0 = ' + str ('{:.2f}'.format (_random.random()*MaxKeq)) + ';  ' + \
+           model += 'k' + str (i+1) + '0 = ' + str ('{:.2f}'.format (_random.random()*keqRatio)) + ';  ' + \
            'k' + str (i+1) + '1 = ' + str ('{:.2f}'.format (_random.random()*1)) + '\n'
            
     model += 'Xo = ' + str ('{:.2f}'.format (_random.randint(1, 10))) + '\n' 
@@ -152,33 +148,11 @@ def _pickReactionType():
        return _TReactionType.BIBI
     
     
+# Generates a reaction network in the form of a reaction list
+# reactionList = [nSpecies, reaction, ....]
+# reaction = [reactionType, [list of reactants], [list of product], rateConstant]
 def generateReactionList (nSpecies, nReactions):
-    """
-    Generates a reaction network in the form of a reaction list
-   
-    Generate a random network using uniuni, unibi, biuni, and bibi reactions.
-    All reactions are governed by mass-action kinetics. User can set the maximum
-    number of reactions and species. 
-      
-    Parameters 
-    ----------
-         arg1 (nSpecies integer): Maximum number of species
-         
-         arg2 (nReaction integer): Maximum number of reactions
-         
-         
-    Return
-    ------
-        result: A nest list describing the reaction network
-                reactionList = [nSpecies, reaction, ....]
-                
-                reaction = [reactionType, [list of reactants], [list of product], rateConstant]
-
-    Example
-    -------
-    >>> model = generateReactionList (6, 9)
-    >>> print (model)     
-    """
+    
     reactionList = []
     for r in range(nReactions):
         
@@ -401,7 +375,7 @@ def getRandomNetwork (nSpecies, nReactions):
     ----------
          arg1 (nSpecies integer): Maximum number of species
          
-         arg2 (nReaction integer): Maximum number of reactions
+         arg2 (nreaction integer): Maximum number of reactions
          
          
     Return
@@ -426,7 +400,7 @@ if __name__ == '__main__' :
    # import heat map code 
    import teUtils as _teUtils
    
-   mod = getLinearChain ('MassAction', 9, MaxKeq=2)
+   mod = getLinearChain ('MassAction', 9, keqRatio=2)
    print (mod)
    r = _te.loada (mod)
    m = r.simulate (0, 100, 200)
